==> ejc-zdsmaterialb-api-3.0.0-20240802.102206-4-sources.jar: com/ejianc/business/zdsmaterial/material/vo/MatInvoiceDetailVO.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 采购发票登记-明细
 *
 * @author generator
 *
 */
public class MatInvoiceDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long mainId; // 主表id
    private Long sourceMainId; // 来源主键id
    private Long sourceId; // 来源id
    private String invoiceCode; // 发票代码
    private String invoiceNumber; // 发票号码
    private Date invoiceDate; // 开票日期
    private String invoiceHeader; // 发票抬头
    private String goodsName; // 货物名称
    private String invoiceCty; // 发票种类
    private BigDecimal rate; // 税率
    private BigDecimal mny; // 发票金额(无税)
    private BigDecimal tax; // 税额
    private BigDecimal taxMny; // 发票金额
    private String erpId; // 领航erpId
    private String invoiceState; // 发票状态
    private Long invoiceId; //发票Id
    private Long invoiceDetailId; //发票子表Id

    public Long getInvoiceId() {
        return invoiceId;
    }

    public void setInvoiceId(Long invoiceId) {
        this.invoiceId = invoiceId;
    }

    public Long getInvoiceDetailId() {
        return invoiceDetailId;
    }

    public void setInvoiceDetailId(Long invoiceDetailId) {
        this.invoiceDetailId = invoiceDetailId;
    }

    public Long getMainId() {
        return mainId;
    }

    public void setMainId(Long mainId) {
        this.mainId = mainId;
    }
    public Long getSourceMainId() {
        return sourceMainId;
    }

    public void setSourceMainId(Long sourceMainId) {
        this.sourceMainId = sourceMainId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }
    public String getInvoiceNumber() {
        return invoiceNumber;
    }

    public void setInvoiceNumber(String invoiceNumber) {
        this.invoiceNumber = invoiceNumber;
    }
    public Date getInvoiceDate() {
        return invoiceDate;
    }

    public void setInvoiceDate(Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }
    public String getInvoiceHeader() {
        return invoiceHeader;
    }

    public void setInvoiceHeader(String invoiceHeader) {
        this.invoiceHeader = invoiceHeader;
    }
    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName;
    }
    public String getInvoiceCty() {
        return invoiceCty;
    }

    public void setInvoiceCty(String invoiceCty) {
        this.invoiceCty = invoiceCty;
    }
    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }
    public String getInvoiceState() {
        return invoiceState;
    }

    public void setInvoiceState(String invoiceState) {
        this.invoiceState = invoiceState;
    }

}

==> ejc-zdsmaterialb-api-3.0.0-20241016.022523-33-sources.jar: com/ejianc/business/zdsmaterial/material/vo/MatInvoiceDetailVO.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 采购发票登记-明细
 *
 * @author generator
 *
 */
public class MatInvoiceDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long mainId; // 主表id
    private Long sourceMainId; // 来源主键id
    private Long sourceId; // 来源id
    private String invoiceCode; // 发票代码
    private String invoiceNumber; // 发票号码
    private Date invoiceDate; // 开票日期
    private String invoiceHeader; // 发票抬头
    private String goodsName; // 货物名称
    private String invoiceCty; // 发票种类
    private BigDecimal rate; // 税率
    private BigDecimal mny; // 发票金额(无税)
    private BigDecimal tax; // 税额
    private BigDecimal taxMny; // 发票金额
    private String erpId; // 领航erpId
    private String invoiceState; // 发票状态
    private Long invoiceId; //发票Id
    private Long invoiceDetailId; //发票子表Id
    private String erpQuoteBillCode; //引用标识：用于记录数据推送ERP前 发票的引用情况，ERP引用单据编码

    public String getErpQuoteBillCode() {
        return erpQuoteBillCode;
    }

    public void setErpQuoteBillCode(String erpQuoteBillCode) {
        this.erpQuoteBillCode = erpQuoteBillCode;
    }

    public Long getInvoiceId() {
        return invoiceId;
    }

    public void setInvoiceId(Long invoiceId) {
        this.invoiceId = invoiceId;
    }

    public Long getInvoiceDetailId() {
        return invoiceDetailId;
    }

    public void setInvoiceDetailId(Long invoiceDetailId) {
        this.invoiceDetailId = invoiceDetailId;
    }

    public Long getMainId() {
        return mainId;
    }

    public void setMainId(Long mainId) {
        this.mainId = mainId;
    }
    public Long getSourceMainId() {
        return sourceMainId;
    }

    public void setSourceMainId(Long sourceMainId) {
        this.sourceMainId = sourceMainId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }
    public String getInvoiceNumber() {
        return invoiceNumber;
    }

    public void setInvoiceNumber(String invoiceNumber) {
        this.invoiceNumber = invoiceNumber;
    }
    public Date getInvoiceDate() {
        return invoiceDate;
    }

    public void setInvoiceDate(Date invoiceDate) {
        this.invoiceDate = invoiceDate;
    }
    public String getInvoiceHeader() {
        return invoiceHeader;
    }

    public void setInvoiceHeader(String invoiceHeader) {
        this.invoiceHeader = invoiceHeader;
    }
    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName;
    }
    public String getInvoiceCty() {
        return invoiceCty;
    }

    public void setInvoiceCty(String invoiceCty) {
        this.invoiceCty = invoiceCty;
    }
    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }
    public String getInvoiceState() {
        return invoiceState;
    }

    public void setInvoiceState(String invoiceState) {
        this.invoiceState = invoiceState;
    }

}
